@@ -498,11 +498,15 @@ class EfiVarList(collections.UserDict):
         self.add_microsoft_kek_keys(ms_kek)
         self.add_dummy_dbx(guids.OvmfEnrollDefaultKeys)
 
-    def add_microsoft_keys(self):
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2011, False)
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2023, False)
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2011, False)
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2023, False)
+    def add_microsoft_keys(self, ms_db = 'all'):
+        if ms_db in ('win11', 'all'):
+            self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2011, False)
+        if ms_db in ('win11', 'win23', 'all'):
+            self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2023, False)
+        if ms_db in ('uefi11', 'all'):
+            self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2011, False)
+        if ms_db in ('uefi11', 'uefi23', 'all'):
+            self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2023, False)
 
     def add_microsoft_kek_keys(self, ms_kek = 'all'):
         if ms_kek in ('2011', 'all'):
